@@ -9,13 +9,9 @@
 #![feature(trusted_len)]
 #![feature(min_specialization)]
 #![feature(decl_macro)]
-#![feature(box_syntax)]
-#![feature(box_into_inner)]
+// test
 #![feature(slice_partition_dedup)]
-#![feature(iter_map_while)]
 #![deny(unsafe_op_in_unsafe_fn)]
-#![deny(unaligned_references)]
-#![warn(rust_2018_idioms)]
 #![warn(deprecated_in_future)]
 #![warn(rust_2021_compatibility)]
 #![warn(rust_2021_prelude_collisions)]
@@ -68,6 +64,8 @@ use std::{
 };
 use write_slice::SpecWriteSlice;
 
+use crate::error::TryReserveErrorKind;
+
 unsafe fn deallocate<T>(ptr: *mut T, capacity: usize) {
     // This unwrap should succeed since the same did when allocating.
     let layout = Layout::array::<T>(capacity).expect("fail ");
@@ -265,13 +263,15 @@ impl<T, const N: usize> SmallVec<T, N> {
             unsafe { deallocate(ptr, cap) };
             self.set_inline();
         } else if new_capacity != cap {
-            let layout = Layout::array::<T>(new_capacity)?;
+            let layout = Layout::array::<T>(new_capacity).unwrap();
             debug_assert!(layout.size() > 0);
             let new_alloc;
             if unspilled {
                 //inline to heap
                 new_alloc = NonNull::new(unsafe { alloc::alloc(layout) })
-                    .ok_or(TryReserveError::AllocError { layout })?
+                    .ok_or(TryReserveError {
+                        kind: TryReserveErrorKind::AllocError { layout },
+                    })?
                     .cast()
                     .as_ptr();
                 unsafe { ptr.copy_to(new_alloc, len) }; //注意
@@ -280,11 +280,13 @@ impl<T, const N: usize> SmallVec<T, N> {
                 // heap
                 // This should never fail since the same succeeded
                 // when previously allocating `ptr`.
-                let old_layout = Layout::array::<T>(cap)?;
+                let old_layout = Layout::array::<T>(cap).unwrap();
 
                 let new_ptr = unsafe { alloc::realloc(ptr as *mut u8, old_layout, layout.size()) };
                 new_alloc = NonNull::new(new_ptr)
-                    .ok_or(TryReserveError::AllocError { layout })?
+                    .ok_or(TryReserveError {
+                        kind: TryReserveErrorKind::AllocError { layout },
+                    })?
                     .cast()
                     .as_ptr();
             }
@@ -325,15 +327,17 @@ impl<T, const N: usize> SmallVec<T, N> {
             self.set_inline();
             unsafe { deallocate(ptr, cap) };
         } else if new_capacity != cap {
-            let layout = Layout::array::<T>(new_capacity)?;
+            let layout = Layout::array::<T>(new_capacity).unwrap();
             debug_assert!(layout.size() > 0);
             // heap
             // This should never fail since the same succeeded
             // when previously allocating `ptr`.
-            let old_layout = Layout::array::<T>(cap)?;
+            let old_layout = Layout::array::<T>(cap).unwrap();
             let new_ptr = unsafe { alloc::realloc(ptr as *mut u8, old_layout, layout.size()) };
             let new_alloc = NonNull::new(new_ptr)
-                .ok_or(TryReserveError::AllocError { layout })?
+                .ok_or(TryReserveError {
+                    kind: TryReserveErrorKind::AllocError { layout },
+                })?
                 .cast()
                 .as_ptr();
 
@@ -390,7 +394,9 @@ impl<T, const N: usize> SmallVec<T, N> {
         let new_cap = len
             .checked_add(additional)
             .and_then(usize::checked_next_power_of_two)
-            .ok_or(TryReserveError::CapacityOverflow)?;
+            .ok_or(TryReserveError {
+                kind: TryReserveErrorKind::CapacityOverflow,
+            })?;
         self.try_grow_to(new_cap)
     }
 
@@ -412,9 +418,9 @@ impl<T, const N: usize> SmallVec<T, N> {
         if cap - len >= additional {
             return Ok(());
         }
-        let new_cap = len
-            .checked_add(additional)
-            .ok_or(TryReserveError::CapacityOverflow)?;
+        let new_cap = len.checked_add(additional).ok_or(TryReserveError {
+            kind: TryReserveErrorKind::CapacityOverflow,
+        })?;
         self.try_grow_to(new_cap)
     }
 
