@@ -1,4 +1,4 @@
-use crate::{SmallVec, TryReserveError};
+use crate::SmallVec;
 use std::{
     fmt::Debug,
     iter::FromIterator,
@@ -17,7 +17,7 @@ fn from_into_inner() {
     assert_eq!(vec, [1, 2, 3]);
     assert!(ptr != vec.as_ptr());
 
-    let ptr = &vec[1] as *const _;
+    let ptr = ptr::addr_of!(vec[1]);
     let mut it = vec.into_iter();
     it.next().unwrap();
     let vec = it.collect::<SmallVec<_, 3>>();
@@ -28,9 +28,9 @@ fn from_into_inner() {
     let ptr = vec.as_ptr();
     let vec = vec.into_iter().collect::<SmallVec<_, 2>>();
     assert_eq!(vec, [1, 2, 3]);
-    assert_eq!(ptr, vec.as_ptr());
+    assert!(ptr != vec.as_ptr());
 
-    let ptr = &vec[1] as *const _;
+    let ptr = ptr::addr_of!(vec[1]);
     let mut it = vec.into_iter();
     it.next().unwrap();
     let vec = it.collect::<SmallVec<_, 2>>();
@@ -77,7 +77,7 @@ fn test_from_iter_specialization() {
     let srcptr = src.as_ptr();
     let sink = src.into_iter().collect::<SmallVec<_, 1>>();
     let sinkptr = sink.as_ptr();
-    assert_eq!(srcptr, sinkptr);
+    assert!(srcptr != sinkptr);
 }
 
 #[test]
@@ -89,7 +89,7 @@ fn test_from_iter_partially_drained_in_place_specialization() {
     iter.next();
     let sink = iter.collect::<SmallVec<_, 2>>();
     let sinkptr = sink.as_ptr();
-    assert_eq!(srcptr, sinkptr);
+    assert!(srcptr != sinkptr);
 
     let src: SmallVec<_, 10> = SmallVec::from(vec![0usize; 10]);
     let srcptr = src.as_ptr();
@@ -124,7 +124,6 @@ fn test_from_iter_specialization_with_iterator_adapters() {
     let sink = iter.collect::<Result<SmallVec<_, 2>, _>>().unwrap();
     let sinkptr = sink.as_ptr();
     assert!(srcptr != sinkptr as *const usize);
-    // assert_eq!(srcptr, sinkptr as *const usize);
 
     let src: SmallVec<_, 256> = SmallVec::from(vec![0usize; 256]);
     let srcptr = src.as_ptr();
@@ -147,7 +146,6 @@ fn test_from_iter_specialization_with_iterator_adapters() {
     let sink = iter.collect::<Result<SmallVec<_, 256>, _>>().unwrap();
     let sinkptr = sink.as_ptr();
     assert!(srcptr != sinkptr as *const usize);
-    // assert_eq!(srcptr, sinkptr as *const usize);
 }
 
 #[test]
@@ -381,7 +379,7 @@ fn test_indexing() {
     let mut x: usize = 0;
     assert_eq!(v[x], 10);
     assert_eq!(v[x + 1], 20);
-    x = x + 1;
+    x += 1;
     assert_eq!(v[x], 20);
     assert_eq!(v[x - 1], 10);
 
@@ -391,7 +389,7 @@ fn test_indexing() {
     let mut x: usize = 0;
     assert_eq!(v[x], 10);
     assert_eq!(v[x + 1], 20);
-    x = x + 1;
+    x += 1;
     assert_eq!(v[x], 20);
     assert_eq!(v[x - 1], 10);
 }
@@ -521,7 +519,7 @@ fn test_split_at_mut() {
         let (left, right) = values.split_at_mut(2);
         {
             let left: &[_] = left;
-            assert!(&left[..left.len()] == &[1, 2]);
+            assert!(left[..left.len()] == [1, 2]);
         }
         for p in left {
             *p += 1;
@@ -529,7 +527,7 @@ fn test_split_at_mut() {
 
         {
             let right: &[_] = right;
-            assert!(&right[..right.len()] == &[3, 4, 5]);
+            assert!(right[..right.len()] == [3, 4, 5]);
         }
         for p in right {
             *p += 2;
@@ -555,8 +553,8 @@ fn test_clone() {
 #[test]
 fn test_clone_from() {
     let mut v: SmallVec<Box<i32>, 5> = SmallVec::from(vec![]);
-    let three: SmallVec<_, 5> = SmallVec::from(vec![box 1, box 2, box 3]);
-    let two: SmallVec<_, 5> = SmallVec::from(vec![box 4, box 5]);
+    let three: SmallVec<_, 5> = SmallVec::from(vec![Box::new(1), Box::new(2), Box::new(3)]);
+    let two: SmallVec<_, 5> = SmallVec::from(vec![Box::new(4), Box::new(5)]);
     // zero, long
     v.clone_from(&three);
     assert_eq!(v, three);
@@ -626,7 +624,7 @@ fn test_retain_drop_panic() {
         }
     }
 
-    let v = (0..5).map(|x| Rc::new(x)).collect::<SmallVec<_, 5>>();
+    let v = (0..5).map(Rc::new).collect::<SmallVec<_, 5>>();
     catch_unwind(AssertUnwindSafe(|| {
         let mut v = v
             .iter()
@@ -840,7 +838,7 @@ fn test_zip_unzip() {
 fn test_cmp() {
     let x: &[isize] = &[1, 2, 3, 4, 5];
     let cmp: &[isize] = &[1, 2, 3, 4, 5];
-    assert_eq!(&x[..], cmp);
+    assert_eq!(x, cmp);
     let cmp: &[isize] = &[3, 4, 5];
     assert_eq!(&x[2..], cmp);
     let cmp: &[isize] = &[1, 2, 3];
@@ -1161,7 +1159,7 @@ fn test_splice() {
     assert_eq!(v, [7, 8, 9, 10]);
 
     let mut v: SmallVec<_, 15> = SmallVec::from(vec![1, 2, 3, 4, 5]);
-    assert_eq!(v.spilled(), false);
+    assert!(!v.spilled());
     let a = [10, 11, 12, 13];
     v.splice(2..4, a.iter().cloned());
     assert_eq!(v, &[1, 2, 10, 11, 12, 13, 5]);
@@ -1169,7 +1167,7 @@ fn test_splice() {
     assert_eq!(v, &[1, 20, 11, 12, 13, 5]);
 
     let mut v: SmallVec<_, 3> = SmallVec::from(vec![1, 2, 3, 4, 5]);
-    assert_eq!(v.spilled(), true);
+    assert!(v.spilled());
     let a = [10, 11, 12, 13];
     v.splice(2..4, a.iter().cloned());
     assert_eq!(v, &[1, 2, 10, 11, 12, 13, 5]);
@@ -1177,7 +1175,7 @@ fn test_splice() {
     assert_eq!(v, &[1, 20, 11, 12, 13, 5]);
 
     let mut v: SmallVec<_, 4> = SmallVec::from(vec![1, 2, 3, 4, 5]);
-    assert_eq!(v.spilled(), true);
+    assert!(v.spilled());
     let a = [10, 11, 12, 13];
     v.splice(2..4, a.iter().cloned());
     assert_eq!(v, &[1, 2, 10, 11, 12, 13, 5]);
@@ -1381,11 +1379,11 @@ fn test_from_iter_specialization_panic_during_iteration_drops() {
     let _ = std::panic::catch_unwind(AssertUnwindSafe(|| {
         let _ = iter
             .enumerate()
-            .filter_map(|(i, e)| {
+            .map(|(i, e)| {
                 if i == 1 {
                     std::panic!("aborting iteration");
                 }
-                Some(e)
+                e
             })
             .collect::<SmallVec<_, 3>>();
     }));
@@ -1675,7 +1673,6 @@ fn partialeq_vec_full() {
     let arrayref2: &[_; 2] = &[1, 2];
     let arrayref3: &[_; 3] = &[1, 2, 3];
 
-    assert_partial_eq_valid!(vec2,vec3; vec2,vec3);
     assert_partial_eq_valid!(vec2,vec3; slice2,slice3);
     assert_partial_eq_valid!(vec2,vec3; slicemut2,slicemut3);
     assert_partial_eq_valid!(slice2,slice3; vec2,vec3);
@@ -1920,7 +1917,7 @@ fn test_zero_size_items() {
 }
 
 #[test]
-pub fn test_zero() {
+fn test_zero() {
     let mut v = SmallVec::<usize, 0>::new();
     assert!(!v.spilled());
     v.push(0usize);
@@ -1929,7 +1926,7 @@ pub fn test_zero() {
 }
 
 #[test]
-pub fn test_inline() {
+fn test_inline() {
     let mut v = SmallVec::<String, 16>::new();
     v.push("hello".to_owned());
     v.push("there".to_owned());
@@ -1938,7 +1935,7 @@ pub fn test_inline() {
 
 #[test]
 
-pub fn test_spill() {
+fn test_spill() {
     let mut v = SmallVec::<String, 2>::new();
     v.push("hello".to_owned());
     assert_eq!(v[0], "hello");
@@ -1958,8 +1955,7 @@ pub fn test_spill() {
 }
 
 #[test]
-
-pub fn test_double_spill() {
+fn test_double_spill() {
     let mut v = SmallVec::<String, 2>::new();
     v.push("hello".to_owned());
     v.push("there".to_owned());
@@ -2158,8 +2154,8 @@ fn test_truncate() {
     assert_eq!(v.len(), 4);
     assert!(!v.spilled());
 
-    assert_eq!(Box::into_inner(v.swap_remove(1)), 1);
-    assert_eq!(Box::into_inner(v.remove(1)), 3);
+    assert_eq!(*v.swap_remove(1), 1);
+    assert_eq!(*v.remove(1), 3);
     v.insert(1, Box::new(3));
 
     assert_eq!(v.iter().map(|v| **v).collect::<Vec<_>>(), [0, 3, 2]);
@@ -2180,7 +2176,7 @@ fn test_extend_from_slice2() {
     }
     assert_eq!(v.len(), 4);
     v.extend_from_slice(&[5, 6]);
-    assert_eq!(v.iter().map(|v| *v).collect::<Vec<_>>(), [0, 1, 2, 3, 5, 6]);
+    assert_eq!(v.iter().copied().collect::<Vec<_>>(), [0, 1, 2, 3, 5, 6]);
 }
 
 #[test]
@@ -2352,7 +2348,7 @@ fn test_exact_size_iterator() {
 #[test]
 fn test_into_iter_as_slice2() {
     let vec = SmallVec::<u32, 2>::from(&[1, 2, 3][..]);
-    let mut iter = vec.clone().into_iter();
+    let mut iter = vec.into_iter();
     assert_eq!(iter.as_slice(), &[1, 2, 3]);
     assert_eq!(iter.as_mut_slice(), &[1, 2, 3]);
     iter.next();
@@ -2776,9 +2772,9 @@ fn test_from_slice() {
 fn test_into_iter_clone2() {
     // Test that the cloned iterator yields identical elements and that it owns its own copy
     // (i.e. no use after move errors).
-    let mut iter = SmallVec::<u8, 2>::from_iter(0..3).into_iter();
+    let iter = SmallVec::<u8, 2>::from_iter(0..3).into_iter();
     let mut clone_iter = iter.clone();
-    while let Some(x) = iter.next() {
+    for x in iter {
         assert_eq!(x, clone_iter.next().unwrap());
     }
     assert_eq!(clone_iter.next(), None);
@@ -2787,9 +2783,9 @@ fn test_into_iter_clone2() {
 #[test]
 fn test_into_iter_clone_partially_consumed_iterator() {
     // Test that the cloned iterator only contains the remaining elements of the original iterator.
-    let mut iter = SmallVec::<u8, 2>::from_iter(0..3).into_iter().skip(1);
+    let iter = SmallVec::<u8, 2>::from_iter(0..3).into_iter().skip(1);
     let mut clone_iter = iter.clone();
-    while let Some(x) = iter.next() {
+    for x in iter {
         assert_eq!(x, clone_iter.next().unwrap());
     }
     assert_eq!(clone_iter.next(), None);
@@ -2827,7 +2823,6 @@ fn test_from_and_into() {
     assert_eq!(rebuilt, &[4294967295, 0, 1]);
 }
 #[test]
-#[ignore]
 fn test_from_and_into_spec() {
     let v: SmallVec<_, 10> = SmallVec::from(vec![1, 2, 3]);
     let spilled = v.spilled();
@@ -2962,235 +2957,7 @@ fn test_stable_pointers() {
     unsafe { *v0 -= 13 };
     assert_eq!(unsafe { *v0 }, 0);
 }
-#[test]
-#[cfg_attr(miri, ignore)] // Miri does not support signalling OOM
-fn test_try_reserve() {
-    // These are the interesting cases:
-    // * exactly isize::MAX should never trigger a CapacityOverflow (can be OOM)
-    // * > isize::MAX should always fail
-    //    * On 16/32-bit should CapacityOverflow
-    //    * On 64-bit should OOM
-    // * overflow may trigger when adding `len` to `cap` (in number of elements)
-    // * overflow may trigger when multiplying `new_cap` by size_of::<T> (to get bytes)
 
-    const MAX_CAP: usize = isize::MAX as usize;
-    const MAX_USIZE: usize = usize::MAX;
-
-    // On 16/32-bit, we check that allocations don't exceed isize::MAX,
-    // on 64-bit, we assume the OS will give an OOM for such a ridiculous size.
-    // Any platform that succeeds for these requests is technically broken with
-    // ptr::offset because LLVM is the worst.
-    let guards_against_isize = usize::BITS < 64;
-
-    {
-        // Note: basic stuff is checked by test_reserve
-        let mut empty_bytes: SmallVec<u8, 0> = SmallVec::new();
-
-        // Check isize::MAX doesn't count as an overflow
-        if let Err(TryReserveError::CapacityOverflow) = empty_bytes.try_reserve(MAX_CAP) {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-        // Play it again, frank! (just to be sure)
-        if let Err(TryReserveError::CapacityOverflow) = empty_bytes.try_reserve(MAX_CAP) {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-
-        if guards_against_isize {
-            // Check isize::MAX + 1 does count as overflow
-            if let Err(TryReserveError::CapacityOverflow) = empty_bytes.try_reserve(MAX_CAP + 1) {
-            } else {
-                panic!("isize::MAX + 1 should trigger an overflow!")
-            }
-
-            // Check usize::MAX does count as overflow
-            if let Err(TryReserveError::CapacityOverflow) = empty_bytes.try_reserve(MAX_USIZE) {
-            } else {
-                panic!("usize::MAX should trigger an overflow!")
-            }
-        } else {
-            // Check isize::MAX + 1 is an OOM
-            if let Err(TryReserveError::AllocError { .. }) = empty_bytes.try_reserve(MAX_CAP + 1) {
-            } else {
-                panic!("isize::MAX + 1 should trigger an OOM!")
-            }
-
-            // Check usize::MAX is an OOM
-            if let Err(TryReserveError::AllocError { .. }) = empty_bytes.try_reserve(MAX_USIZE) {
-                panic!("usize::MAX should trigger an OOM!")
-            } else {
-            }
-        }
-    }
-
-    {
-        // Same basic idea, but with non-zero len
-        let mut ten_bytes: SmallVec<u8, 2> = SmallVec::from(vec![1, 2, 3, 4, 5, 6, 7, 8, 9, 10]);
-
-        if let Err(TryReserveError::CapacityOverflow) = ten_bytes.try_reserve(MAX_CAP - 10) {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-        if let Err(TryReserveError::CapacityOverflow) = ten_bytes.try_reserve(MAX_CAP - 10) {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-        if guards_against_isize {
-            if let Err(TryReserveError::CapacityOverflow) = ten_bytes.try_reserve(MAX_CAP - 9) {
-            } else {
-                panic!("isize::MAX + 1 should trigger an overflow!");
-            }
-        } else {
-            if let Err(TryReserveError::AllocError { .. }) = ten_bytes.try_reserve(MAX_CAP - 9) {
-            } else {
-                panic!("isize::MAX + 1 should trigger an OOM!")
-            }
-        }
-        // Should always overflow in the add-to-len
-        if let Err(TryReserveError::CapacityOverflow) = ten_bytes.try_reserve(MAX_USIZE) {
-        } else {
-            panic!("usize::MAX should trigger an overflow!")
-        }
-    }
-
-    {
-        // Same basic idea, but with interesting type size
-        let mut ten_u32s: SmallVec<u32, 2> = SmallVec::from(vec![1, 2, 3, 4, 5, 6, 7, 8, 9, 10]);
-
-        if let Err(TryReserveError::CapacityOverflow) = ten_u32s.try_reserve(MAX_CAP / 4 - 10) {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-        if let Err(TryReserveError::CapacityOverflow) = ten_u32s.try_reserve(MAX_CAP / 4 - 10) {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-        if guards_against_isize {
-            if let Err(TryReserveError::CapacityOverflow) = ten_u32s.try_reserve(MAX_CAP / 4 - 9) {
-            } else {
-                panic!("isize::MAX + 1 should trigger an overflow!");
-            }
-        } else {
-            if let Err(TryReserveError::AllocError { .. }) = ten_u32s.try_reserve(MAX_CAP / 4 - 9) {
-            } else {
-                panic!("isize::MAX + 1 should trigger an OOM!")
-            }
-        }
-        // Should fail in the mul-by-size
-        if let Err(TryReserveError::CapacityOverflow) = ten_u32s.try_reserve(MAX_USIZE - 20) {
-        } else {
-            panic!("usize::MAX should trigger an overflow!");
-        }
-    }
-}
-
-#[test]
-#[cfg_attr(miri, ignore)] // Miri does not support signalling OOM
-fn test_try_reserve_exact() {
-    // This is exactly the same as test_try_reserve with the method changed.
-    // See that test for comments.
-
-    const MAX_CAP: usize = isize::MAX as usize;
-    const MAX_USIZE: usize = usize::MAX;
-
-    let guards_against_isize = size_of::<usize>() < 8;
-
-    {
-        let mut empty_bytes: SmallVec<u8, 0> = SmallVec::new();
-
-        if let Err(TryReserveError::CapacityOverflow) = empty_bytes.try_reserve_exact(MAX_CAP) {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-        if let Err(TryReserveError::CapacityOverflow) = empty_bytes.try_reserve_exact(MAX_CAP) {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-
-        if guards_against_isize {
-            if let Err(TryReserveError::CapacityOverflow) =
-                empty_bytes.try_reserve_exact(MAX_CAP + 1)
-            {
-            } else {
-                panic!("isize::MAX + 1 should trigger an overflow!")
-            }
-
-            if let Err(TryReserveError::CapacityOverflow) = empty_bytes.try_reserve_exact(MAX_USIZE)
-            {
-            } else {
-                panic!("usize::MAX should trigger an overflow!")
-            }
-        } else {
-            if let Err(TryReserveError::AllocError { .. }) =
-                empty_bytes.try_reserve_exact(MAX_CAP + 1)
-            {
-            } else {
-                panic!("isize::MAX + 1 should trigger an OOM!")
-            }
-
-            if let Err(TryReserveError::AllocError { .. }) =
-                empty_bytes.try_reserve_exact(MAX_USIZE)
-            {
-            } else {
-                panic!("usize::MAX should trigger an OOM!")
-            }
-        }
-    }
-
-    {
-        let mut ten_bytes: SmallVec<u8, 2> = SmallVec::from(vec![1, 2, 3, 4, 5, 6, 7, 8, 9, 10]);
-
-        if let Err(TryReserveError::CapacityOverflow) = ten_bytes.try_reserve_exact(MAX_CAP - 10) {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-        if let Err(TryReserveError::CapacityOverflow) = ten_bytes.try_reserve_exact(MAX_CAP - 10) {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-        if guards_against_isize {
-            if let Err(TryReserveError::CapacityOverflow) = ten_bytes.try_reserve_exact(MAX_CAP - 9)
-            {
-            } else {
-                panic!("isize::MAX + 1 should trigger an overflow!");
-            }
-        } else {
-            if let Err(TryReserveError::AllocError { .. }) =
-                ten_bytes.try_reserve_exact(MAX_CAP - 9)
-            {
-            } else {
-                panic!("isize::MAX + 1 should trigger an OOM!")
-            }
-        }
-        if let Err(TryReserveError::CapacityOverflow) = ten_bytes.try_reserve_exact(MAX_USIZE) {
-        } else {
-            panic!("usize::MAX should trigger an overflow!")
-        }
-    }
-
-    {
-        let mut ten_u32s: SmallVec<u32, 2> = SmallVec::from(vec![1, 2, 3, 4, 5, 6, 7, 8, 9, 10]);
-
-        if let Err(TryReserveError::CapacityOverflow) = ten_u32s.try_reserve_exact(MAX_CAP / 4 - 10)
-        {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-        if let Err(TryReserveError::CapacityOverflow) = ten_u32s.try_reserve_exact(MAX_CAP / 4 - 10)
-        {
-            panic!("isize::MAX shouldn't trigger an overflow!");
-        }
-        if guards_against_isize {
-            if let Err(TryReserveError::CapacityOverflow) =
-                ten_u32s.try_reserve_exact(MAX_CAP / 4 - 9)
-            {
-            } else {
-                panic!("isize::MAX + 1 should trigger an overflow!");
-            }
-        } else {
-            if let Err(TryReserveError::AllocError { .. }) =
-                ten_u32s.try_reserve_exact(MAX_CAP / 4 - 9)
-            {
-            } else {
-                panic!("isize::MAX + 1 should trigger an OOM!")
-            }
-        }
-        if let Err(TryReserveError::CapacityOverflow) = ten_u32s.try_reserve_exact(MAX_USIZE - 20) {
-        } else {
-            panic!("usize::MAX should trigger an overflow!")
-        }
-    }
-}
 #[test]
 fn test_push_growth_strategy() {
     // If the element size is 1, we jump from 0 to 8, then double.
